==> owncloud-9.0.3.tgz: owncloud/apps/files_external/l10n/it.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di richiesta non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di accesso non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Please provide a valid app key and secret." : "Fornisci chiave e segreto dell'applicazione validi.",
    "Step 1 failed. Exception: %s" : "Fase 1 non riuscita. Eccezione: %s",
    "Step 2 failed. Exception: %s" : "Fase 2 non riuscita. Eccezione: %s",
    "External storage" : "Archiviazione esterna",
    "Storage with id \"%i\" not found" : "Archiviazione con ID \"%i\" non trovata",
    "Invalid backend or authentication mechanism class" : "Motore o classe del meccanismo di autenticazione non valido",
    "Invalid mount point" : "Punto di mount non valido",
    "Objectstore forbidden" : "Objectstore vietato",
    "Invalid storage backend \"%s\"" : "Motore di archiviazione \"%s\" non valido",
    "Not permitted to use backend \"%s\"" : "Utilizzo del motore \"%s\" non permesso",
    "Not permitted to use authentication mechanism \"%s\"" : "Utilizzo del meccanismo di autenticazione \"%s\" non permesso",
    "Unsatisfied backend parameters" : "Parametri del motore non soddisfatti",
    "Unsatisfied authentication mechanism parameters" : "Parametri del meccanismo di autenticazione non soddisfatti",
    "Insufficient data: %s" : "Dati insufficienti: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "L'archiviazione con ID \"%i\" non è modificabile dall'utente",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Grant access" : "Concedi l'accesso",
    "Access granted" : "Accesso consentito",
    "Error configuring OAuth1" : "Errore di configurazione OAuth1",
    "Error configuring OAuth2" : "Errore di configurazione OAuth2",
    "Generate keys" : "Genera la chiavi",
    "Error generating key pair" : "Errore durante la generazione della coppia di chiavi",
    "Enable encryption" : "Abilita cifratura",
    "Enable previews" : "Abilita le anteprime",
    "Enable sharing" : "Abilita condivisione",
    "Check for changes" : "Controlla le modifiche",
    "Never" : "Mai",
    "Once every direct access" : "Una volta per ogni accesso diretto",
    "All users. Type to select user or group." : "Tutti gli utenti. Digita per selezionare utente o gruppo.",
    "(group)" : "(gruppo)",
    "Admin defined" : "Definito dall'amministratore",
    "Saved" : "Salvato",
    "Empty response from the server" : "Risposta vuota dal server",
    "Couldn't access. Please logout and login to activate this mount point" : "Impossibile accedere. Chiudi la sessione e accedi nuovamente per attivare questo punto di mount",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Impossibile ottenere le informazioni dal server ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Impossibile ottenere l'elenco dei punti di mount esterni: {type}",
    "There was an error with message: " : "Si è verificato un errore con il messaggio:",
    "External mount error" : "Errore di mount esterno",
    "external-storage" : "archiviazione-esterna",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Impossibile ottenere l'elenco dei punti di mount delle unità di rete Windows: risposta vuota dal server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alcuni dei punti di mount esterni configurati non sono connessi. Fai clic sulle righe rosse per ulteriori informazioni",
    "Please enter the credentials for the {mount} mount" : "Digita le credenziali per montare {mount}",
    "Username" : "Nome utente",
    "Password" : "Password",
    "Credentials saved" : "Credenziali salvate",
    "Credentials saving failed" : "Salvataggio delle credenziali non riuscito",
    "Credentials required" : "Credenziali richieste",
    "Save" : "Salva",
    "Access key" : "Chiave di accesso",
    "Secret key" : "Chiave segreta",
    "Builtin" : "Integrata",
    "None" : "Nessuno",
    "OAuth1" : "OAuth1",
    "App key" : "Chiave applicazione",
    "App secret" : "Segreto applicazione",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID client",
    "Client secret" : "Segreto del client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nome tenant",
    "Identity endpoint URL" : "URL endpoint delle identità",
    "Rackspace" : "Rackspace",
    "API key" : "Chiave API",
    "Username and password" : "Nome utente e password",
    "Log-in credentials, save in session" : "Credenziali di accesso, salva nella sessione",
    "RSA public key" : "Chiave pubblica RSA",
    "Public key" : "Chiave pubblica",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome host",
    "Port" : "Porta",
    "Region" : "Regione",
    "Enable SSL" : "Abilita SSL",
    "Enable Path Style" : "Abilita stile percorsi",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sottocartella remota",
    "Secure https://" : "Sicuro https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicuro ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Locale",
    "Location" : "Posizione",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Radice",
    "SFTP with secret key login" : "SFTP con accesso a chiave segreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Condividi",
    "Domain" : "Dominio",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizzando le credenziali di OC",
    "Username as share" : "Nome utente come condivisione",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nome servizio",
    "Request timeout (seconds)" : "Tempo massimo della richiesta (secondi)",
    "<b>Note:</b> " : "<b>Nota:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> il supporto a cURL di PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> il supporto a FTP in PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> \"%s\" non è installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "No external storage configured" : "Nessuna archiviazione esterna configurata",
    "You can add external storages in the personal settings" : "Puoi aggiungere archiviazioni esterne nelle impostazioni personali",
    "Name" : "Nome",
    "Storage type" : "Tipo di archiviazione",
    "Scope" : "Ambito",
    "External Storage" : "Archiviazione esterna",
    "Folder name" : "Nome della cartella",
    "Authentication" : "Autenticazione",
    "Configuration" : "Configurazione",
    "Available for" : "Disponibile per",
    "Add storage" : "Aggiungi archiviazione",
    "Advanced settings" : "Impostazioni avanzate",
    "Delete" : "Elimina",
    "Allow users to mount external storage" : "Consenti agli utenti di montare archiviazioni esterne",
    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente archiviazione esterna",
    "SMB / CIFS" : "SMB / CIFS",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alcuni dei punti di mount esterni configurati non sono connessi. Fai clic sulle righe rosse per ulteriori informazioni"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_external/l10n/it.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di richiesta non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Il recupero dei token di accesso non è riuscito. Verifica che la chiave e il segreto dell'applicazione siano corretti.",
    "Please provide a valid app key and secret." : "Fornisci chiave e segreto dell'applicazione validi.",
    "Step 1 failed. Exception: %s" : "Fase 1 non riuscita. Eccezione: %s",
    "Step 2 failed. Exception: %s" : "Fase 2 non riuscita. Eccezione: %s",
    "External storage" : "Archiviazione esterna",
    "Dropbox App Configuration" : "Configurazione applicazione Dropbox",
    "Google Drive App Configuration" : "Configurazione applicazione Google Drive",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Grant access" : "Concedi l'accesso",
    "Error configuring OAuth1" : "Errore di configurazione OAuth1",
    "Error configuring OAuth2" : "Errore di configurazione OAuth2",
    "Generate keys" : "Genera la chiavi",
    "Error generating key pair" : "Errore durante la generazione della coppia di chiavi",
    "All users. Type to select user or group." : "Tutti gli utenti. Digita per selezionare utente o gruppo.",
    "(group)" : "(gruppo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilità con la codifica Mac NFD (lento)",
    "Admin defined" : "Definito dall'amministratore",
    "Saved" : "Salvato",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Disabilitare gli archivi esterni smonterà tutte le archiviazioni di tutti gli utenti, sei sicuro ?",
    "Disable external storage" : "Disabilita archiviazione esterna",
    "Empty response from the server" : "Risposta vuota dal server",
    "Couldn't access. Please logout and login to activate this mount point" : "Impossibile accedere. Chiudi la sessione e accedi nuovamente per attivare questo punto di mount",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Impossibile ottenere le informazioni dal server ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Impossibile ottenere l'elenco dei punti di mount esterni: {type}",
    "There was an error with message: " : "Si è verificato un errore con il messaggio:",
    "External mount error" : "Errore di mount esterno",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Impossibile ottenere l'elenco dei punti di mount delle unità di rete Windows: risposta vuota dal server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alcuni dei punti di mount esterni configurati non sono connessi. Fai clic sulle righe rosse per ulteriori informazioni",
    "Please enter the credentials for the {mount} mount" : "Digita le credenziali per montare {mount}",
    "Username" : "Nome utente",
    "Password" : "Password",
    "Credentials saved" : "Credenziali salvate",
    "Credentials saving failed" : "Salvataggio delle credenziali non riuscito",
    "Credentials required" : "Credenziali richieste",
    "Save" : "Salva",
    "Storage with id \"%i\" not found" : "Archiviazione con ID \"%i\" non trovata",
    "Invalid backend or authentication mechanism class" : "Motore o classe del meccanismo di autenticazione non valido",
    "Invalid mount point" : "Punto di mount non valido",
    "Objectstore forbidden" : "Objectstore vietato",
    "Invalid storage backend \"%s\"" : "Motore di archiviazione \"%s\" non valido",
    "Not permitted to use backend \"%s\"" : "Utilizzo del motore \"%s\" non permesso",
    "Not permitted to use authentication mechanism \"%s\"" : "Utilizzo del meccanismo di autenticazione \"%s\" non permesso",
    "Unsatisfied backend parameters" : "Parametri del motore non soddisfatti",
    "Unsatisfied authentication mechanism parameters" : "Parametri del meccanismo di autenticazione non soddisfatti",
    "Insufficient data: %s" : "Dati insufficienti: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "L'archiviazione con ID \"%i\" non è modificabile dall'utente",
    "Access key" : "Chiave di accesso",
    "Secret key" : "Chiave segreta",
    "OAuth1" : "OAuth1",
    "App key" : "Chiave applicazione",
    "App secret" : "Segreto applicazione",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID client",
    "Client secret" : "Segreto del client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nome tenant",
    "Identity endpoint URL" : "URL endpoint delle identità",
    "Rackspace" : "Rackspace",
    "API key" : "Chiave API",
    "RSA public key" : "Chiave pubblica RSA",
    "Public key" : "Chiave pubblica",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome host",
    "Port" : "Porta",
    "Region" : "Regione",
    "Enable SSL" : "Abilita SSL",
    "Enable Path Style" : "Abilita stile percorsi",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sottocartella remota",
    "Secure https://" : "Sicuro https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Locale",
    "Location" : "Posizione",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Host",
    "Root" : "Radice",
    "SFTP with secret key login" : "SFTP con accesso a chiave segreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Condividi",
    "Domain" : "Dominio",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizzando le credenziali di OC",
    "Username as share" : "Nome utente come condivisione",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nome servizio",
    "Request timeout (seconds)" : "Tempo massimo della richiesta (secondi)",
    "<b>Note:</b> " : "<b>Nota:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> il supporto a cURL di PHP non è abilitato o installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> \"%s\" non è installato. Impossibile montare %s. Chiedi al tuo amministratore di sistema di installarlo.",
    "No external storage configured" : "Nessuna archiviazione esterna configurata",
    "You can add external storages in the storage settings" : "Puoi aggiungere archivi esterni tramite impostazioni archivi ",
    "Name" : "Nome",
    "Storage type" : "Tipo di archiviazione",
    "Scope" : "Ambito",
    "Enable encryption" : "Abilita cifratura",
    "Enable previews" : "Abilita le anteprime",
    "Enable sharing" : "Abilita condivisione",
    "Check for changes" : "Controlla le modifiche",
    "Never" : "Mai",
    "Once every direct access" : "Una volta per ogni accesso diretto",
    "External Storage" : "Archiviazione esterna",
    "Enable external storage" : "Abilita archiviazione esterna",
    "External storage has been disabled by the administrator" : "Gli archivi esterni sono stati disabilitati dall'amministratore",
    "Folder name" : "Nome della cartella",
    "Authentication" : "Autenticazione",
    "Configuration" : "Configurazione",
    "Available for" : "Disponibile per",
    "Add storage" : "Aggiungi archiviazione",
    "Advanced settings" : "Impostazioni avanzate",
    "Delete" : "Elimina",
    "Allow users to mount external storage" : "Consenti agli utenti di montare archiviazioni esterne",
    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente archiviazione esterna"
},
"nplurals=2; plural=(n != 1);");
